==> Pyrogram-0.14.1.tar.gz: Pyrogram-0.14.1/pyrogram/client/methods/bots/get_game_high_scores.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from typing import Union

import pyrogram
from pyrogram.api import functions
from pyrogram.client.ext import BaseClient


class GetGameHighScores(BaseClient):
    def get_game_high_scores(
        self,
        user_id: Union[int, str],
        chat_id: Union[int, str],
        message_id: int = None
    ) -> "pyrogram.GameHighScores":
        """Get data for high score tables.

        Parameters:
            user_id (``int`` | ``str``):
                Unique identifier (int) or username (str) of the target chat.
                For your personal cloud (Saved Messages) you can simply use "me" or "self".
                For a contact that exists in your Telegram address book you can use his phone number (str).

            chat_id (``int`` | ``str``, *optional*):
                Unique identifier (int) or username (str) of the target chat.
                For your personal cloud (Saved Messages) you can simply use "me" or "self".
                For a contact that exists in your Telegram address book you can use his phone number (str).
                Required if inline_message_id is not specified.

            message_id (``int``, *optional*):
                Identifier of the sent message.
                Required if inline_message_id is not specified.

        Returns:
            :obj:`GameHighScores`: On success.

        Raises:
            RPCError: In case of a Telegram RPC error.
        """
        # TODO: inline_message_id

        return pyrogram.GameHighScores._parse(
            self,
            self.send(
                functions.messages.GetGameHighScores(
                    peer=self.resolve_peer(chat_id),
                    id=message_id,
                    user_id=self.resolve_peer(user_id)
                )
            )
        )

==> Pyrogram-0.16.0.tar.gz: Pyrogram-0.16.0/pyrogram/client/methods/bots/get_game_high_scores.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from typing import Union, List

import pyrogram
from pyrogram.api import functions
from pyrogram.client.ext import BaseClient


class GetGameHighScores(BaseClient):
    def get_game_high_scores(
        self,
        user_id: Union[int, str],
        chat_id: Union[int, str],
        message_id: int = None
    ) -> List["pyrogram.GameHighScore"]:
        """Get data for high score tables.

        Parameters:
            user_id (``int`` | ``str``):
                Unique identifier (int) or username (str) of the target chat.
                For your personal cloud (Saved Messages) you can simply use "me" or "self".
                For a contact that exists in your Telegram address book you can use his phone number (str).

            chat_id (``int`` | ``str``, *optional*):
                Unique identifier (int) or username (str) of the target chat.
                For your personal cloud (Saved Messages) you can simply use "me" or "self".
                For a contact that exists in your Telegram address book you can use his phone number (str).
                Required if inline_message_id is not specified.

            message_id (``int``, *optional*):
                Identifier of the sent message.
                Required if inline_message_id is not specified.

        Returns:
            List of :obj:`GameHighScore`: On success.

        Example:
            .. code-block:: python

                scores = app.get_game_high_scores(user_id, chat_id, message_id)
                print(scores)
        """
        # TODO: inline_message_id

        r = self.send(
            functions.messages.GetGameHighScores(
                peer=self.resolve_peer(chat_id),
                id=message_id,
                user_id=self.resolve_peer(user_id)
            )
        )

        return pyrogram.List(pyrogram.GameHighScore._parse(self, score, r.users) for score in r.scores)
